@@ -28,19 +28,25 @@ ags_plugin_browser_plugin_type_changed_callback(GtkWidget *combo_box,
     gtk_widget_show(plugin_browser->lv2_browser);
 
     gtk_widget_hide(plugin_browser->ladspa_browser);
+#if defined(AGS_WITH_VST3)
     gtk_widget_hide(plugin_browser->vst3_browser);
+#endif
   }else if(gtk_combo_box_get_active((GtkComboBox *) combo_box) == 1){
     plugin_browser->active_browser = plugin_browser->ladspa_browser;
     gtk_widget_show(plugin_browser->ladspa_browser);
 
     gtk_widget_hide(plugin_browser->lv2_browser);
+#if defined(AGS_WITH_VST3)
     gtk_widget_hide(plugin_browser->vst3_browser);
+#endif
+#if defined(AGS_WITH_VST3)
   }else if(gtk_combo_box_get_active((GtkComboBox *) combo_box) == 2){
     plugin_browser->active_browser = plugin_browser->vst3_browser;
     gtk_widget_show(plugin_browser->vst3_browser);
 
     gtk_widget_hide(plugin_browser->lv2_browser);
     gtk_widget_hide(plugin_browser->ladspa_browser);
+#endif
   }
 }
 
