@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2021 Joël Krähemann
+ * Copyright (C) 2005-2022 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -143,20 +143,27 @@ ags_fm_oscillator_init(AgsFMOscillator *fm_oscillator)
   GtkListStore *model;
   GtkTreeIter iter;
 
+  AgsConfig *config;
+
+  guint samplerate;
   guint i;
 
+  config = ags_config_get_instance();
+  
   fm_oscillator->flags = 0;
   
   grid = (GtkGrid *) gtk_grid_new();
   gtk_container_add((GtkContainer *) fm_oscillator,
 		    (GtkWidget *) grid);
 
+  samplerate = ags_soundcard_helper_config_get_samplerate(config);
+
+  /* wave */
   gtk_grid_attach(grid,
 		  (GtkWidget *) gtk_label_new(i18n("wave")),
 		  0, 0,
 		  1, 1);
 
-  /* wave */
   fm_oscillator->wave = (GtkComboBox *) gtk_combo_box_text_new();
   gtk_grid_attach(grid,
 		  (GtkWidget *) fm_oscillator->wave,
@@ -224,7 +231,8 @@ ags_fm_oscillator_init(AgsFMOscillator *fm_oscillator)
 		  4, 0,
 		  1, 1);
   fm_oscillator->frame_count = (GtkSpinButton *) gtk_spin_button_new_with_range(0.0, 100000.0, 1.0);
-  gtk_spin_button_set_value(fm_oscillator->frame_count, AGS_FM_OSCILLATOR_DEFAULT_FRAME_COUNT);
+  gtk_spin_button_set_value(fm_oscillator->frame_count,
+			    AGS_FM_OSCILLATOR_DEFAULT_FRAME_COUNT * ((gdouble) samplerate / AGS_FM_OSCILLATOR_DEFAULT_SAMPLERATE));
   gtk_grid_attach(grid, (GtkWidget *) fm_oscillator->frame_count,
 		  5, 0,
 		  1, 1);
