@@ -23,12 +23,10 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#define GSEQUENCER_RT_PRIORITY (95)
-
 void ags_test_enter();
 void ags_test_leave();
 
-pthread_mutex_t* ags_test_get_driver_mutex();
+GRecMutex* ags_test_get_driver_mutex();
 
 void ags_test_init(int *argc, char ***argv,
 		   gchar *conf_str);
@@ -43,11 +41,7 @@ void ags_test_signal_cleanup();
 
 void ags_test_setup(int argc, char **argv);
 
-void ags_test_start_animation(pthread_t *thread);
-void* ags_test_start_animation_thread(void *ptr);
-
-void ags_test_launch(gboolean single_thread);
-void ags_test_launch_filename(gchar *filename,
-			      gboolean single_thread);
+void ags_test_launch();
+void ags_test_launch_filename(gchar *filename);
 
 #endif /*__GSEQUENCER_TEST_SETUP_UTIL_H__*/
